@@ -6,6 +6,7 @@ standardized logging and exception handling.
 import logging
 from abc import ABC
 from abc import abstractmethod
+from contextlib import contextmanager
 from string import ascii_letters
 from typing import Optional
 
@@ -13,25 +14,45 @@ import elasticapm
 import pkg_resources
 from hashids import Hashids
 
+__all__ = ["TaskBase"]
 
 logger = logging.getLogger(__name__)
 
 
 class ApmTransaction:
     """
-    Elastic APM transaction manager for a DAG Task
+    Elastic APM transaction manager for a DAG Task.
+        Without configuration it self disables
     """
 
-    def __init__(self, transaction_name: str, apm_client_config: dict) -> None:
-        self.transaction_name = transaction_name
-        self.client = elasticapm.Client(apm_client_config)
-        elasticapm.instrument()
-        self.client.begin_transaction(self.transaction_name)
+    def __init__(self, transaction_name: str, apm_client_config: Optional[dict] = None) -> None:
+        self.configured = bool(apm_client_config)
+        if self.configured:
+            self.transaction_name = transaction_name
+            self.client = elasticapm.Client(apm_client_config)
+            elasticapm.instrument()
+            self.client.begin_transaction(self.transaction_name)
+
+    @contextmanager
+    def capture_span(self, name: str, *args, **kwargs):
+        if not self.configured:
+            try:
+                yield
+            finally:
+                pass
+        else:
+            try:
+                with elasticapm.capture_span(name, *args, **kwargs):
+                    yield
+            finally:
+                pass
 
     def __enter__(self):
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
+        if not self.configured:
+            return
         if exc_type:
             self.client.capture_exception()
         # End the APM transaction
@@ -43,7 +64,14 @@ class ApmTransaction:
 class TaskBase(ABC):
     """
     Generic wrapper for the DAG tasks providing a standard interface and execution flow
-    Each DAG task must implement its own subclass of this abstract wrapper class
+    Each DAG task must implement its own subclass of this abstract wrapper class.
+    Intended instantiation is as a context manager
+    >>> class RealTask(TaskBase):
+    >>>     def run(self):
+    >>>         pass
+    >>>
+    >>> with RealTask(1, "a", "b") as task:
+    >>>     task()
     """
 
     retries = 3
@@ -83,7 +111,7 @@ class TaskBase(ABC):
 
     def record_provenance(self):
         """
-        Method that must be overridden to record provenance
+        Method that can be overridden to record provenance
         """
 
     @abstractmethod
@@ -103,23 +131,27 @@ class TaskBase(ABC):
         -------
         None
         """
-        logger.info(f"Task {self.task_name} started")
-        if not self.apm_client_configuration:
-            self.run()
-            self.record_provenance()
-            return
 
+        logger.info(f"Task {self.task_name} started")
         with ApmTransaction(
             transaction_name=self.task_name, apm_client_config=self.apm_client_configuration
-        ):
-            with elasticapm.capture_span("Run"):
+        ) as apm:
+            with apm.capture_span("Run"):
                 self.run()
-            with elasticapm.capture_span("Record provenance"):
+            with apm.capture_span("Record provenance"):
                 self.record_provenance()
         logger.info(f"Task {self.task_name} complete")
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        """
+        Method that can be overridden to execute teardown tasks after task execution
+        """
+
     def __repr__(self):
         return f"{self.__class__.__name__}(recipe_run_id={self.recipe_run_id}, workflow_name={self.workflow_name}, workflow_version={self.workflow_version}, is_task_manual={self.is_task_manual}, apm_client_config={self.apm_client_configuration})"
 
     def __str__(self):
-        return self.__repr__()
+        return repr(self)
