@@ -4,6 +4,7 @@ Global test fixtures
 from configparser import ConfigParser
 from contextlib import contextmanager
 from pathlib import Path
+from shutil import rmtree
 from typing import Any
 from typing import List
 from typing import Tuple
@@ -18,6 +19,13 @@ from dkist_processing_core._node import Node
 from dkist_processing_core.tests.task_example import Task
 
 
+@pytest.fixture(scope="module")
+def export_path() -> str:
+    path = Path("export/")
+    yield str(path)
+    rmtree(path)
+
+
 @pytest.fixture(scope="session")
 def task_subclass():
     """
@@ -55,7 +63,10 @@ def task_instance(task_subclass):
     """
     Create an instance of the task subclass defined in task_subclass
     """
-    return task_subclass(recipe_run_id=1, workflow_name="workflow_name", workflow_version="version")
+    with task_subclass(
+        recipe_run_id=1, workflow_name="workflow_name", workflow_version="version"
+    ) as task:
+        yield task
 
 
 @pytest.fixture()
@@ -79,7 +90,7 @@ def workflow():
     """
     Create an instance of the Workflow abstraction without tasks
     """
-    name = "wr0kflow"
+    name = "instrument_calibration_name"
     version = "V6-12342"
     workflow_instance = Workflow(workflow_name=name, workflow_version=version)
     return workflow_instance, name, version
