@@ -4,7 +4,7 @@ Test minimal dependency dag export (used for scheduler deployments)
 import pytest
 
 
-def test_workflow_export(workflow_tasks, workflow):
+def test_workflow_export(workflow_tasks, workflow, export_path):
     """
     Given: A workflow instance with tasks in the
       structure of A >> [B, C] >> D
@@ -23,7 +23,7 @@ def test_workflow_export(workflow_tasks, workflow):
         workflow_instance.add_node(task, upstreams=upstream)
 
     # When
-    dag_file = workflow_instance.export()
+    dag_file = workflow_instance.export(export_path)
     # Then
     with dag_file.open(mode="r") as f:
         compile(f.read(), filename=f"{name}_{version}.pyc", mode="exec")
