@@ -2,10 +2,13 @@
 Tests for the Workflow abstraction
 """
 from pathlib import Path
+from typing import Callable
 
 import pytest
 from airflow import DAG
 
+from dkist_processing_core import Workflow
+
 
 def test_workflow_metadata(workflow):
     """
@@ -14,11 +17,30 @@ def test_workflow_metadata(workflow):
     Then: Tha values are properly assigned
     """
     workflow_instance, name, version = workflow
+
+    instrument = name.split("_")[0]
+    calibration = "_".join(name.split("_")[1:])
+
     assert workflow_instance.workflow_name == name
     assert workflow_instance.workflow_version == version
     assert workflow_instance.nodes == []
     assert isinstance(workflow_instance._dag, DAG)
     assert workflow_instance._dag.dag_id == f"{name}_{version}"
+    assert workflow_instance._instrument_name == instrument
+    assert workflow_instance._calibration_name == calibration
+    assert workflow_instance._dag_tags == f'["{instrument}", "{calibration}", "{version}"]'
+
+
+def test_workflow_bad_metadata():
+    """
+    Given: Workflow Class
+    When: Instance is created with non-convention workflow name
+    Then: Tags are expected unknown variants
+    """
+    name = "badname"
+    w = Workflow(workflow_name=name)
+    assert w._instrument_name == "InstrumentUnknown"
+    assert w._calibration_name == "CalibrationUnknown"
 
 
 def test_workflow_add_node(workflow_tasks, workflow):
@@ -74,3 +96,22 @@ def test_invalid_workflow_add_node(workflow):
 
     with pytest.raises(TypeError):
         workflow_instance.add_node(Task)
+
+
+@pytest.mark.parametrize(
+    "func, attr",
+    [
+        pytest.param(repr, "__repr__", id="repr"),
+        pytest.param(str, "__str__", id="str"),
+    ],
+)
+def test_tag_db_dunder(workflow, func: Callable, attr):
+    """
+    Given: Connection to a tag database
+    When: retrieving dunder method that should be implemented
+    Then: It is implemented
+    """
+    workflow_instance, _, _ = workflow
+
+    assert getattr(workflow_instance, attr, None)
+    assert func(workflow_instance)
